tlslite.utils.Cryptlib_AES.Cryptlib_AES

Package tlslite :: Package utils :: Module Cryptlib_AES :: Class Cryptlib_AES |
[show private | hide private]
[frames | no frames]

## Class Cryptlib_AES

    AES --+
          |
         Cryptlib_AES

Method Summary
| `__init__(self, key, mode, IV)`
| `__del__(self)`
| `decrypt(self, ciphertext)`
| `encrypt(self, plaintext)`

Generated by Epydoc 2.0 on Mon Feb 21 21:56:55 2005 | http://epydoc.sf.net